总览
==================

准备工作
----------------

1. :doc:`针对你的任务构建关联结构 </zh/tutorial/structure>`。
2. :doc:`针对你的任务构建输入数据 </zh/tutorial/dataset>`。
3. :doc:`针对你的任务构建模型 </zh/tutorial/model>`。
4. :doc:`针对你的任务构建指标度量器 </zh/tutorial/metric>`。


训练和评测
------------------------------

1. :doc:`构建你的训练和评测代码 </zh/tutorial/train>`。
2. :doc:`自动超参调优 </zh/tutorial/auto_ml>`。


其他
-----------

- :doc:`随机关联结构的生成 </zh/tutorial/random>`。
- :doc:`关联结构可视化 </zh/tutorial/vis_structure>`。
- :doc:`特征可视化 </zh/tutorial/vis_feature>`。

